Package: polmineR
Type: Package
Title: Verbs and Nouns for Corpus Analysis
Version: 0.8.9
Date: 2023-10-29
Authors@R: c(
  person("Andreas", "Blaette", role = c("aut", "cre"), email = "andreas.blaette@uni-due.de", comment = c(ORCID = "0000-0001-8970-8010")),
  person("Christoph", "Leonhardt", role = "ctb"),
  person("Marius", "Bertram", role = "ctb")
  )
Depends: R (>= 3.5.0)
Imports: methods, data.table (>= 1.12.2), fs, slam, Matrix, tm, DT,
        xml2, stringi, utils, jsonlite, parallel, pbapply, RcppCWB (>=
        0.6.2), magrittr, knitr, lifecycle, rlang, cli
Suggests: markdown (>= 1.5), rmarkdown, htmltools (>= 0.4.0),
        highlight, sendmailR, shiny, shinythemes, shinyjs, miniUI,
        rhandsontable, testthat, tidytext, covr, igraph, NLP, httr,
        protolite, curl
VignetteBuilder: knitr
Description: Package for corpus analysis using the Corpus Workbench 
    ('CWB', <https://cwb.sourceforge.io>) as an efficient back end for indexing
    and querying large corpora. The package offers functionality to flexibly create
    subcorpora and to carry out basic statistical operations (count, co-occurrences
    etc.). The original full text of documents can be reconstructed and inspected at
    any time. Beyond that, the package is intended to serve as an interface to 
    packages implementing advanced statistical procedures. Respective data structures
    (document-term matrices, term-co-occurrence matrices etc.) can be created based 
    on the indexed corpora.
BugReports: https://github.com/PolMine/polmineR/issues
Biarch: true
License: GPL-3
URL: https://github.com/PolMine/polmineR
Encoding: UTF-8
Collate: 'polmineR.R' 'S4classes.R' 'p_attributes.R' 'textstat.R'
        'bundle.R' 'corpus.R' 'count.R' 'partition.R'
        'partition_bundle.R' 'ngrams.R' 'features.R' 'context.R'
        'TermDocumentMatrix.R' 'annotations.R' 'as.VCorpus.R'
        'as.markdown.R' 'kwic.R' 'decode.R' 'cooccurrences.R'
        'as.sparseMatrix.R' 'as.speeches.R' 'blapply.R' 'coerce.R'
        'hits.R' 'cpos.R' 'dispersion.R' 'dotplot.R' 'encoding.R'
        'enrich.R' 'format.R' 'highlight.R' 'href.R' 'html.R' 'info.R'
        'means.R' 'noise.R' 'opencpu.R' 'phrases.R'
        'polmineR-defunct.R' 'ranges.R' 'regions.R' 'read.R'
        'registry.R' 'reindex.R' 'renamed.R' 'restore.R'
        's_attributes.R' 'size.R' 'split.R' 'stats.R' 'subset.R'
        'templates.R' 'terms.R' 'token_stream.R' 'tooltips.R'
        'tree_structure.R' 'trim.R' 'type.R' 'use.R' 'utils.R' 'view.R'
        'weigh.R' 'zzz.R'
RoxygenNote: 7.2.3
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2023-10-29 21:34:33 UTC; andreasblatte
Author: Andreas Blaette [aut, cre] (<https://orcid.org/0000-0001-8970-8010>),
  Christoph Leonhardt [ctb],
  Marius Bertram [ctb]
Maintainer: Andreas Blaette <andreas.blaette@uni-due.de>
Repository: CRAN
Date/Publication: 2023-10-29 21:50:02 UTC
Built: R 4.6.0; ; 2026-04-25 13:16:20 UTC; unix
