# Generated by roxygen2: do not edit by hand

S3method(as.data.table,bundle)
S3method(as.data.table,ranges)
S3method(as.data.table,regions)
S3method(as.data.table,textstat)
S3method(as.list,bundle)
export("%>%")
export()
export(as.corpusEnc)
export(as.cqp)
export(as.data.table)
export(as.nativeEnc)
export(as.partitionBundle)
export(as.utf8)
export(browse)
export(capitalize)
export(check_cqp_query)
export(concatenate_phrases)
export(cooccurrences)
export(cp)
export(data_dir)
export(flatten)
export(getEncoding)
export(getTerms)
export(getTokenStream)
export(get_info)
export(href)
export(is.cqp)
export(is.partition)
export(is_nested)
export(mail)
export(ocpu_exec)
export(pAttributes)
export(partitionBundle)
export(partition_bundle)
export(polmineR)
export(punctuation)
export(registry)
export(registry_get_encoding)
export(registry_get_home)
export(registry_get_id)
export(registry_get_info)
export(registry_get_name)
export(registry_get_p_attributes)
export(registry_get_properties)
export(registry_get_s_attributes)
export(registry_move)
export(registry_reset)
export(restore)
export(sAttributes)
export(show_info)
export(trim)
export(use)
exportClasses(Cooccurrences)
exportClasses(bundle)
exportClasses(context)
exportClasses(cooccurrences)
exportClasses(cooccurrences_bundle)
exportClasses(corpus)
exportClasses(count)
exportClasses(count_bundle)
exportClasses(features)
exportClasses(features_cooccurrences)
exportClasses(features_ngrams)
exportClasses(hits)
exportClasses(kwic)
exportClasses(ngrams)
exportClasses(partition)
exportClasses(partition_bundle)
exportClasses(ranges)
exportClasses(regions)
exportClasses(remote_corpus)
exportClasses(remote_partition)
exportClasses(remote_subcorpus)
exportClasses(slice)
exportClasses(subcorpus)
exportClasses(subcorpus_bundle)
exportClasses(textstat)
exportMethods("$")
exportMethods("$<-")
exportMethods("+")
exportMethods("[")
exportMethods("[[")
exportMethods("[[<-")
exportMethods("annotations<-")
exportMethods("encoding<-")
exportMethods("name<-")
exportMethods("names<-")
exportMethods(Cooccurrences)
exportMethods(aggregate)
exportMethods(annotations)
exportMethods(as.DocumentTermMatrix)
exportMethods(as.TermDocumentMatrix)
exportMethods(as.VCorpus)
exportMethods(as.bundle)
exportMethods(as.character)
exportMethods(as.data.frame)
exportMethods(as.list)
exportMethods(as.markdown)
exportMethods(as.matrix)
exportMethods(as.partition_bundle)
exportMethods(as.phrases)
exportMethods(as.regions)
exportMethods(as.simple_triplet_matrix)
exportMethods(as.sparseMatrix)
exportMethods(as.speeches)
exportMethods(as_igraph)
exportMethods(barplot)
exportMethods(blapply)
exportMethods(chisquare)
exportMethods(colnames)
exportMethods(context)
exportMethods(cooccurrences)
exportMethods(corpus)
exportMethods(count)
exportMethods(cpos)
exportMethods(decode)
exportMethods(dim)
exportMethods(dispersion)
exportMethods(dotplot)
exportMethods(edit)
exportMethods(encoding)
exportMethods(enrich)
exportMethods(features)
exportMethods(format)
exportMethods(get_corpus)
exportMethods(get_template)
exportMethods(get_token_stream)
exportMethods(get_type)
exportMethods(head)
exportMethods(highlight)
exportMethods(hist)
exportMethods(hits)
exportMethods(html)
exportMethods(knit_print)
exportMethods(kwic)
exportMethods(length)
exportMethods(ll)
exportMethods(merge)
exportMethods(name)
exportMethods(names)
exportMethods(ncol)
exportMethods(ngrams)
exportMethods(noise)
exportMethods(nrow)
exportMethods(p_attributes)
exportMethods(partition)
exportMethods(partition_bundle)
exportMethods(pmi)
exportMethods(ranges)
exportMethods(read)
exportMethods(regions)
exportMethods(round)
exportMethods(s_attributes)
exportMethods(sample)
exportMethods(show)
exportMethods(size)
exportMethods(sort)
exportMethods(split)
exportMethods(subset)
exportMethods(summary)
exportMethods(tail)
exportMethods(terms)
exportMethods(tooltips)
exportMethods(tree_structure)
exportMethods(view)
exportMethods(weigh)
import(methods)
importFrom(DT,dataTableProxy)
importFrom(DT,datatable)
importFrom(DT,formatStyle)
importFrom(DT,replaceData)
importFrom(Matrix,colSums)
importFrom(Matrix,rowSums)
importFrom(Matrix,sparseMatrix)
importFrom(RcppCWB,cl_attribute_size)
importFrom(RcppCWB,cl_charset_name)
importFrom(RcppCWB,cl_cpos2id)
importFrom(RcppCWB,cl_cpos2lbound)
importFrom(RcppCWB,cl_cpos2rbound)
importFrom(RcppCWB,cl_cpos2str)
importFrom(RcppCWB,cl_cpos2struc)
importFrom(RcppCWB,cl_id2cpos)
importFrom(RcppCWB,cl_id2freq)
importFrom(RcppCWB,cl_id2str)
importFrom(RcppCWB,cl_lexicon_size)
importFrom(RcppCWB,cl_load_corpus)
importFrom(RcppCWB,cl_regex2id)
importFrom(RcppCWB,cl_str2id)
importFrom(RcppCWB,cl_struc2cpos)
importFrom(RcppCWB,cl_struc2str)
importFrom(RcppCWB,cl_struc_values)
importFrom(RcppCWB,corpus_data_dir)
importFrom(RcppCWB,corpus_full_name)
importFrom(RcppCWB,corpus_info_file)
importFrom(RcppCWB,corpus_p_attributes)
importFrom(RcppCWB,corpus_properties)
importFrom(RcppCWB,corpus_property)
importFrom(RcppCWB,corpus_registry_dir)
importFrom(RcppCWB,corpus_s_attributes)
importFrom(RcppCWB,cqp_dump_subcorpus)
importFrom(RcppCWB,cqp_get_registry)
importFrom(RcppCWB,cqp_initialize)
importFrom(RcppCWB,cqp_is_initialized)
importFrom(RcppCWB,cqp_list_corpora)
importFrom(RcppCWB,cqp_load_corpus)
importFrom(RcppCWB,cqp_query)
importFrom(RcppCWB,cqp_reset_registry)
importFrom(RcppCWB,get_cbow_matrix)
importFrom(RcppCWB,get_region_matrix)
importFrom(RcppCWB,ranges_to_cpos)
importFrom(RcppCWB,region_matrix_context)
importFrom(RcppCWB,region_matrix_to_ids)
importFrom(RcppCWB,region_matrix_to_struc_matrix)
importFrom(RcppCWB,s_attr_is_descendent)
importFrom(RcppCWB,s_attr_is_sibling)
importFrom(RcppCWB,s_attr_regions)
importFrom(RcppCWB,s_attr_relationship)
importFrom(RcppCWB,s_attribute_decode)
importFrom(cli,bg_br_yellow)
importFrom(cli,cli_alert_danger)
importFrom(cli,cli_alert_info)
importFrom(cli,cli_alert_success)
importFrom(cli,cli_alert_warning)
importFrom(cli,cli_bullets)
importFrom(cli,cli_process_done)
importFrom(cli,cli_process_start)
importFrom(cli,cli_progress_bar)
importFrom(cli,cli_progress_done)
importFrom(cli,cli_progress_step)
importFrom(cli,cli_progress_update)
importFrom(cli,col_blue)
importFrom(cli,col_cyan)
importFrom(cli,col_red)
importFrom(data.table,as.data.table)
importFrom(data.table,between)
importFrom(data.table,copy)
importFrom(data.table,data.table)
importFrom(data.table,dcast)
importFrom(data.table,dcast.data.table)
importFrom(data.table,fread)
importFrom(data.table,key)
importFrom(data.table,melt.data.table)
importFrom(data.table,rbindlist)
importFrom(data.table,setDT)
importFrom(data.table,setDTthreads)
importFrom(data.table,setcolorder)
importFrom(data.table,setindexv)
importFrom(data.table,setkey)
importFrom(data.table,setkeyv)
importFrom(data.table,setnames)
importFrom(data.table,setorderv)
importFrom(data.table,truelength)
importFrom(fs,path)
importFrom(fs,path_expand)
importFrom(grDevices,colors)
importFrom(graphics,dotchart)
importFrom(graphics,grid)
importFrom(graphics,par)
importFrom(graphics,plot)
importFrom(graphics,points)
importFrom(graphics,rect)
importFrom(graphics,text)
importFrom(jsonlite,fromJSON)
importFrom(jsonlite,toJSON)
importFrom(knitr,knit_print)
importFrom(lifecycle,deprecate_warn)
importFrom(magrittr,"%>%")
importFrom(parallel,detectCores)
importFrom(parallel,mclapply)
importFrom(pbapply,pblapply)
importFrom(pbapply,pbsapply)
importFrom(rlang,enquo)
importFrom(rlang,eval_tidy)
importFrom(rlang,is_quosure)
importFrom(rlang,quo_get_expr)
importFrom(rlang,quo_set_expr)
importFrom(slam,as.simple_triplet_matrix)
importFrom(slam,col_sums)
importFrom(slam,row_sums)
importFrom(slam,simple_triplet_matrix)
importFrom(stats,formula)
importFrom(stats,ftable)
importFrom(stats,na.omit)
importFrom(stats,setNames)
importFrom(stats,xtabs)
importFrom(stringi,stri_c)
importFrom(stringi,stri_enc_mark)
importFrom(stringi,stri_encode)
importFrom(stringi,stri_extract_all_boundaries)
importFrom(stringi,stri_match_all_regex)
importFrom(stringi,stri_sub)
importFrom(tm,DocumentTermMatrix)
importFrom(tm,TermDocumentMatrix)
importFrom(tm,as.DocumentTermMatrix)
importFrom(tm,as.TermDocumentMatrix)
importFrom(tm,as.VCorpus)
importFrom(tm,nDocs)
importFrom(tm,stopwords)
importFrom(utils,View)
importFrom(utils,browseURL)
importFrom(utils,capture.output)
importFrom(utils,download.file)
importFrom(utils,edit)
importFrom(utils,localeToCharset)
importFrom(utils,menu)
importFrom(utils,packageVersion)
importFrom(utils,setTxtProgressBar)
importFrom(utils,txtProgressBar)
importFrom(utils,untar)
importFrom(utils,write.csv)
importFrom(xml2,"xml_attr<-")
importFrom(xml2,"xml_text<-")
importFrom(xml2,read_html)
importFrom(xml2,xml_attr)
importFrom(xml2,xml_attrs)
importFrom(xml2,xml_child)
importFrom(xml2,xml_contents)
importFrom(xml2,xml_find_all)
importFrom(xml2,xml_find_first)
importFrom(xml2,xml_name)
importFrom(xml2,xml_parent)
importFrom(xml2,xml_remove)
importFrom(xml2,xml_text)
importFrom(xml2,xml_type)
